@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization
+  Copyright @ 2002 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.  You may
@@ -68,9 +68,12 @@ extern MagickExport char
   **GetLogList(const char *,size_t *,ExceptionInfo *);
 
 extern MagickExport const char
-  *GetLogName(void),
+  *GetLogName(void) magick_attribute((__pure__)),
   *SetLogName(const char *);
 
+extern MagickExport const LogEventType
+  GetLogEventMask(void) magick_attribute((__pure__));
+
 extern MagickExport const LogInfo
   **GetLogInfoList(const char *,size_t *,ExceptionInfo *);
 
